==> fmriprep-23.1.0rc1.tar.gz: fmriprep-23.1.0rc1/.maint/CONTRIBUTORS.md <==
# CONTRIBUTORS

This document lists those who have made contributions to the Project.
As per the contributor guidelines, they should be included by default in any publications derived from the Project.

If you are new to the project, don't forget to add your name and affiliation to the list of contributors here! Our Welcome Bot will send an automated message reminding this to first-time contributors.
Before every release, unlisted contributors will be invited again to add their names to this file (just in case they missed the automated message from our Welcome Bot).

| **Lastname** | **Name** | **Handle** | **ORCID** | **Affiliation** |
| --- | --- | --- | --- | --- |
| Adebimpe          | Azeez        |  | 0000-0001-9049-0135 | Perelman School of Medicine, University of Pennsylvania, PA, USA                                                                             |
| Amlien            | Inge K.      |  | 0000-0002-8508-9088 | Center for Lifespan Changes in Brain and Cognition, University of Oslo                                                                       |
| Bellec            | Pierre       |  | 0000-0002-9111-0699 | SIMEXP Lab, CRIUGM, University of Montréal, Montréal, Canada                                                                                 |
| Benson            | Noah C.      |  | 0000-0002-2365-8265 | Department of Psychology, New York University                                                                                                |
| Bhagwat           | Nikhil       |  | 0000-0001-6073-7141 | Montreal Neurological Institute, McGill University                                                                                           |
| Cieslak           | Matthew      |  | 0000-0002-1931-4734 | Perelman School of Medicine, University of Pennsylvania, PA, USA                                                                             |
| de la Vega        | Alejandro    |  | 0000-0001-9062-3778 | University of Texas at Austin                                                                                                                |
| Devenyi           | Grabriel A.  |  | 0000-0002-7766-1187 | Department of Psychiatry, McGill University                                                                                                  |
| Erramuzpe         | Asier        |  | 0000-0002-9402-2184 | Computational Neuroimaging Lab, BioCruces Health Research Institute                                                                          |
| Feingold          | Franklin     |  | 0000-0002-6533-2909 | Department of Psychology, Stanford University                                                                                                |
| Finc              | Karolina     |  | 0000-0002-0157-030X | Centre for Modern Interdisciplinary Technologies, Nicolaus Copernicus University in Toruń                                                    |
| Frederick         | Blaise B.    |  | 0000-0001-5832-5279 | ['McLean Hospital Brain Imaging Center, MA, USA', 'Consolidated Department of Psychiatry, Harvard Medical School, MA, USA']                  |
| Groen             | Iris I. A.   |  | 0000-0002-5536-6128 | Department of Psychology, New York University, NY, USA                                                                                       |
| Gomez             | Daniel E. P. |  | 0000-0001-8635-021X | Donders Institute for Brain, Cognition and Behaviour, Radboud University Nijmegen                                                            |
| Ghosh             | Satrajit S.  |  | 0000-0002-5312-6729 | ['McGovern Institute for Brain Research, MIT, MA, USA', 'Department of Otolaryngology, Harvard Medical School, MA, USA']                     |
| Halchenko         | Yaroslav O.  |  | 0000-0003-3456-2493 | Dartmouth College: Hanover, NH, United States                                                                                                |
| Heinsfeld         | Anibal S.    |  | 0000-0002-2050-0614 | Child Mind Institute                                                                                                                         |
| Isik              | Ayse Ilkay   |  | 0000-0002-1652-9297 | Max Planck Institute for Empirical Aesthetics                                                                                                |
| Jacoby            | Nir          |  | 0000-0001-7936-9991 | Department of Psychology, Columbia University                                                                                                |
| Jamison           | Keith W.     |  | 0000-0001-7139-6661 | Department of Radiology, Weill Cornell Medicine                                                                                              |
| Liem              | Franz        |  | 0000-0003-0646-4810 | URPP Dynamics of Healthy Aging, University of Zurich                                                                                         |
| Lurie             | Daniel J.    |  | 0000-0001-8012-6399 | Department of Psychology, University of California, Berkeley                                                                                 |
| Ma                | Feilong      |  | 0000-0002-6838-3971 | Dartmouth College: Hanover, NH, United States                                                                                                |
| Mentch            | Jeff         |  | 0000-0002-7762-8678 | Speech & Hearing Bioscience & Technology Program, Harvard University                                                                         |
| Moodie            | Craig A.     |  | 0000-0003-0867-1469 | Department of Psychology, Stanford University                                                                                                |
| Naveau            | Mikaël       |  | 0000-0001-6948-9068 | Cyceron, UMS 3408 (CNRS - UCBN), France                                                                                                      |
| Nitsch            | Alexander    |  | 0000-0002-5740-9451 | Max Planck Institute for Human Cognitive and Brain Sciences, Leipzig, Germany                                                                |
| Plunkett          | Dillon       |  | 0000-0001-7822-6024 | Department of Psychology, Harvard University                                                                                                 |
| Provins           | Céline       |  | 0000-0002-1668-9629 | Department of Radiology, Lausanne University Hospital and University of Lausanne                                                             |
| Rivera-Dompenciel | Adriana      |  | 0000-0002-3339-4857 | Neuroscience Program, University of Iowa                                                                                                     |
| Satterthwaite     | Theodore D.  |  | 0000-0001-7072-9399 | Perelman School of Medicine, University of Pennsylvania, PA, USA                                                                             |
| Schaefer          | Theo A.J.    |  | 0000-0003-4102-559X | Max Planck Institute for Human Cognitive and Brain Sciences, Leipzig, Germany                                                                |
| Sitek             | Kevin R.     |  | 0000-0002-2172-5786 | Speech & Hearing Bioscience & Technology Program, Harvard University                                                                         |
| Smith             | Robert E.    |  | 0000-0003-3636-4642 | Florey Institute of Neuroscience and Mental Health                                                                                           |
| Sneve             | Markus H.    |  | 0000-0001-7644-7915 | Center for Lifespan Changes in Brain and Cognition, University of Oslo                                                                       |
| Stojić            | Hrvoje       |  | 0000-0002-9699-9052 | Max Planck UCL Centre for Computational Psychiatry and Ageing Research, University College London                                            |
| Thompson          | William H.   |  | 0000-0002-0533-6035 | Department of Psychology, Stanford University                                                                                                |
| Tooley            | Ursula A.    |  | 0000-0001-6377-3885 | Department of Neuroscience, University of Pennsylvania, PA, USA                                                                              |
| Urchs             | Sebastian    |  | 0000-0001-5504-8579 | Montreal Neurological Institute, McGill University                                                                                           |
| Valabregue        | Romain       |  | 0000-0002-1814-9570 | CENIR, INSERM U1127, CNRS UMR 7225, UPMC Univ Paris 06 UMR S 1127, Institut du Cerveau et de la Moelle épinière, ICM, F-75013, Paris, France |
| Velasco           | Pablo        |  | 0000-0002-5749-6049 | Center for Brain Imaging, New York University                                                                                                |
| Waller            | Lea          |  | 0000-0002-3239-6957 | Charite Universitatsmedizin Berlin, Germany                                                                                                  |
| Wexler            | Joseph B.    |  | 0000-0001-6424-8740 | Department of Psychology, Stanford University                                                                                                |
| Wright            | Jessey       |  | 0000-0001-5504-8579 | Department of Psychology, Stanford University                                                                                                |
| Ye                | Zhifang      |  | 0000-0003-0489-2619 | State Key Laboratory of Cognitive Neuroscience and Learning, Beijing Normal University                                                       |

==> fmriprep-23.2.0.tar.gz: fmriprep-23.2.0/.maint/CONTRIBUTORS.md <==
# CONTRIBUTORS

This document lists those who have made contributions to the Project.
As per the contributor guidelines, they should be included by default in any publications derived from the Project.

If you are new to the project, don't forget to add your name and affiliation to the list of contributors here! Our Welcome Bot will send an automated message reminding this to first-time contributors.
Before every release, unlisted contributors will be invited again to add their names to this file (just in case they missed the automated message from our Welcome Bot).

| **Lastname** | **Name** | **Handle** | **ORCID** | **Affiliation** |
| --- | --- | --- | --- | --- |
| Adebimpe          | Azeez        |  | 0000-0001-9049-0135 | Perelman School of Medicine, University of Pennsylvania, PA, USA                                                                             |
| Amlien            | Inge K.      |  | 0000-0002-8508-9088 | Center for Lifespan Changes in Brain and Cognition, University of Oslo                                                                       |
| Bellec            | Pierre       |  | 0000-0002-9111-0699 | SIMEXP Lab, CRIUGM, University of Montréal, Montréal, Canada                                                                                 |
| Benson            | Noah C.      |  | 0000-0002-2365-8265 | Department of Psychology, New York University                                                                                                |
| Bhagwat           | Nikhil       |  | 0000-0001-6073-7141 | Montreal Neurological Institute, McGill University                                                                                           |
| Cieslak           | Matthew      |  | 0000-0002-1931-4734 | Perelman School of Medicine, University of Pennsylvania, PA, USA                                                                             |
| de la Vega        | Alejandro    |  | 0000-0001-9062-3778 | University of Texas at Austin                                                                                                                |
| Devenyi           | Grabriel A.  |  | 0000-0002-7766-1187 | Department of Psychiatry, McGill University                                                                                                  |
| Erramuzpe         | Asier        |  | 0000-0002-9402-2184 | Computational Neuroimaging Lab, BioCruces Health Research Institute                                                                          |
| Feingold          | Franklin     |  | 0000-0002-6533-2909 | Department of Psychology, Stanford University                                                                                                |
| Finc              | Karolina     |  | 0000-0002-0157-030X | Centre for Modern Interdisciplinary Technologies, Nicolaus Copernicus University in Toruń                                                    |
| Frederick         | Blaise B.    |  | 0000-0001-5832-5279 | McLean Hospital Brain Imaging Center, MA, USA                                                                                                |
| Groen             | Iris I. A.   |  | 0000-0002-5536-6128 | Department of Psychology, New York University, NY, USA                                                                                       |
| Gomez             | Daniel E. P. |  | 0000-0001-8635-021X | Donders Institute for Brain, Cognition and Behaviour, Radboud University Nijmegen                                                            |
| Ghosh             | Satrajit S.  |  | 0000-0002-5312-6729 | McGovern Institute for Brain Research, MIT, MA, USA                                                                                          |
| Halchenko         | Yaroslav O.  |  | 0000-0003-3456-2493 | Dartmouth College: Hanover, NH, United States                                                                                                |
| Heinsfeld         | Anibal S.    |  | 0000-0002-2050-0614 | Child Mind Institute                                                                                                                         |
| Isik              | Ayse Ilkay   |  | 0000-0002-1652-9297 | Max Planck Institute for Empirical Aesthetics                                                                                                |
| Jacoby            | Nir          |  | 0000-0001-7936-9991 | Department of Psychology, Columbia University                                                                                                |
| Jamison           | Keith W.     |  | 0000-0001-7139-6661 | Department of Radiology, Weill Cornell Medicine                                                                                              |
| Kruper            | John         |  | 0000-0003-0081-391X | Department of Psychology, University of Washington                                                                                           |
| Liem              | Franz        |  | 0000-0003-0646-4810 | URPP Dynamics of Healthy Aging, University of Zurich                                                                                         |
| Lurie             | Daniel J.    |  | 0000-0001-8012-6399 | Department of Psychology, University of California, Berkeley                                                                                 |
| Ma                | Feilong      |  | 0000-0002-6838-3971 | Dartmouth College: Hanover, NH, United States                                                                                                |
| Madison           | Thomas       |  | 0000-0003-3030-6580 | Department of Pediatrics, University of Minnesota, MN, USA                                                                                   |
| Mentch            | Jeff         |  | 0000-0002-7762-8678 | Speech & Hearing Bioscience & Technology Program, Harvard University                                                                         |
| Moodie            | Craig A.     |  | 0000-0003-0867-1469 | Department of Psychology, Stanford University                                                                                                |
| Naveau            | Mikaël       |  | 0000-0001-6948-9068 | Cyceron, UMS 3408 (CNRS - UCBN), France                                                                                                      |
| Nielson           | Dylan M.     |  | 0000-0003-4613-6643 | Machine Learning Team, National Institute of Mental Health, USA                                                                              |
| Nitsch            | Alexander    |  | 0000-0002-5740-9451 | Max Planck Institute for Human Cognitive and Brain Sciences, Leipzig, Germany                                                                |
| Papadopoulos      | Dimitri      |  | 0000-0002-1242-8990 | Neurospin, CEA                                                                                                                               |
| Plunkett          | Dillon       |  | 0000-0001-7822-6024 | Department of Psychology, Harvard University                                                                                                 |
| Provins           | Céline       |  | 0000-0002-1668-9629 | Department of Radiology, Lausanne University Hospital and University of Lausanne                                                             |
| Rivera-Dompenciel | Adriana      |  | 0000-0002-3339-4857 | Neuroscience Program, University of Iowa                                                                                                     |
| Satterthwaite     | Theodore D.  |  | 0000-0001-7072-9399 | Perelman School of Medicine, University of Pennsylvania, PA, USA                                                                             |
| Schaefer          | Theo A.J.    |  | 0000-0003-4102-559X | Max Planck Institute for Human Cognitive and Brain Sciences, Leipzig, Germany                                                                |
| Sitek             | Kevin R.     |  | 0000-0002-2172-5786 | Speech & Hearing Bioscience & Technology Program, Harvard University                                                                         |
| Smith             | Robert E.    |  | 0000-0003-3636-4642 | Florey Institute of Neuroscience and Mental Health                                                                                           |
| Sneve             | Markus H.    |  | 0000-0001-7644-7915 | Center for Lifespan Changes in Brain and Cognition, University of Oslo                                                                       |
| Stojić            | Hrvoje       |  | 0000-0002-9699-9052 | Max Planck UCL Centre for Computational Psychiatry and Ageing Research, University College London                                            |
| Thompson          | William H.   |  | 0000-0002-0533-6035 | Department of Psychology, Stanford University                                                                                                |
| Tooley            | Ursula A.    |  | 0000-0001-6377-3885 | Department of Neuroscience, University of Pennsylvania, PA, USA                                                                              |
| Urchs             | Sebastian    |  | 0000-0001-5504-8579 | Montreal Neurological Institute, McGill University                                                                                           |
| Valabregue        | Romain       |  | 0000-0002-1814-9570 | CENIR, INSERM U1127, CNRS UMR 7225, UPMC Univ Paris 06 UMR S 1127, Institut du Cerveau et de la Moelle épinière, ICM, F-75013, Paris, France |
| Velasco           | Pablo        |  | 0000-0002-5749-6049 | Center for Brain Imaging, New York University                                                                                                |
| Waller            | Lea          |  | 0000-0002-3239-6957 | Charite Universitatsmedizin Berlin, Germany                                                                                                  |
| Wexler            | Joseph B.    |  | 0000-0001-6424-8740 | Department of Psychology, Stanford University                                                                                                |
| Wright            | Jessey       |  | 0000-0001-5504-8579 | Department of Psychology, Stanford University                                                                                                |
| Ye                | Zhifang      |  | 0000-0003-0489-2619 | State Key Laboratory of Cognitive Neuroscience and Learning, Beijing Normal University                                                       |
